/*****************************************************************************
 ** 
 ** kisdndock.h
 ** 
 ** Copyright 2000  by Red Hat GmbH
 **
 ** Author:   Thomas Woerner (thomas.woerner@redhat.de)
 ** 
 *****************************************************************************/

#ifndef KISDNDOCK_H
#define KISDNDOCK_H

#include <qlabel.h>
#include <qwidget.h>
#include <qtimer.h>
#include <qdatetime.h>
#include <qfileinfo.h>
#include <qtooltip.h>
#include <qtextstream.h>
#include <qstringlist.h>
#include <qpainter.h>

#include <provider.h>

#include <linux/isdn.h>
#include <linux/isdnif.h>

#include <kmainwindow.h>
#include <kiconloader.h>
#include <kaboutdata.h>

#define PROC_NET "/proc/net/dev"
#define PROC_ROUTE "/proc/net/route"
#define DEV_ISDNINFO "/dev/isdninfo"
#define DEV_ISDNCTRL "/dev/isdnctrl"
#define IFCFG_PREFIX "/etc/sysconfig/network-scripts/ifcfg-"
#define GRAPH_SIZE 24

typedef struct {
    unsigned long ibytes;
    unsigned long obytes;
} IOBytes;


class KISDNdock: public KMainWindow {
    Q_OBJECT

  protected:
    KPopupMenu      *menu;
    int             dial;
    int             hangup;
    QList<Provider> provider;
    QTimer          *timer;
    QDateTime       var_run_time;
    uint            var_run_size;
    QPixmap         *pixmap;
    QPainter        painter;

    int             isdninfo_fd;
    int             isdnctrl_fd;

    IOBytes         iobytes[ISDN_MAX_CHANNELS];

    bool            is_trying(int);
    bool            is_active(int);
    void            get_index(int);
     
    void            mousePressEvent(QMouseEvent*);
    void            paintEvent(QPaintEvent *);
    unsigned int    graph[GRAPH_SIZE];

    int             info_fd(bool errfatal = true);
    int             ctrl_fd(bool errfatal = true);

  public:
    KISDNdock();
    ~KISDNdock();

    static const KAboutData *aboutData();
    
  protected slots:
    void            load();
    void            activateMenu(int);
    void            update();
};

#endif /* KISDNDOCK_H */
// vim:ts=4:sw=4
