#include "kisdndockconfig.h"
#include <kaboutdata.h>
#include <klocale.h>
#include <kprocess.h>
#include <kconfig.h>

KIsdnDockConfig::KIsdnDockConfig(QWidget *parent, const char *name):KCModule(parent, name)
{
	layout=new QVBoxLayout(this, 10, 10);
	layout->setResizeMode(QLayout::Minimum);
	launch_kisdndock=new QCheckBox(i18n("&Launch kisdndock at KDE startup"), this);
	layout->addWidget(launch_kisdndock);
	connect(launch_kisdndock, SIGNAL(clicked()), this, SLOT(configChanged()));
	launch_rcn=new QPushButton(i18n("Run &redhat-config-network to configure ISDN devices"), this);
	layout->addWidget(launch_rcn);
	connect(launch_rcn, SIGNAL(clicked()), this, SLOT(rcn()));
	launch_druid=new QPushButton(i18n("Run &internet-druid to configure ISDN devices"), this);
	layout->addWidget(launch_druid);
	connect(launch_druid, SIGNAL(clicked()), this, SLOT(druid()));
	QSpacerItem *spacer=new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Expanding);
	layout->addItem(spacer);
	load();
}

void KIsdnDockConfig::save()
{
	KConfig *config = new KConfig("kisdndockrc");
	config->setReadOnly(false);
	config->setGroup("RedHat");
	config->writeEntry("AutoStart", launch_kisdndock->isChecked());
	config->sync();
	emit changed(false);
}

void KIsdnDockConfig::load()
{
	KConfig *config = new KConfig("kisdndockrc");
	config->setGroup("RedHat");
	launch_kisdndock->setChecked(config->readBoolEntry("AutoStart", false));
	emit changed(false);
}

void KIsdnDockConfig::defaults()
{
	bool oldstate=launch_kisdndock->isChecked();
	launch_kisdndock->setChecked(true);
	if(!oldstate)
		emit changed(true);
}

const KAboutData *KIsdnDockConfig::aboutData() const
{
	static KAboutData* ab = 0;
	if(!ab)
	{
		ab = new KAboutData("kcmkisdndock", I18N_NOOP("KIsdnDockConfig"),
				"1.0.0", I18N_NOOP("Red Hat ISDN Dock Configurator"),
				KAboutData::License_GPL, 0, 0, 0);
		ab->addAuthor("Bernhard \"Bero\" Rosenkrnzer", 0, "bero@redhat.com");
		ab->addAuthor("Than Ngo", 0, "than@redhat.com");
	}
	return ab;
}

QString KIsdnDockConfig::quickHelp() const
{
	return i18n("<h1>KIsdnDock</h1>This applet controls the KDE ISDN Dock.<br>KIsdnDock allows you to connect and disconnect from ISDN links quickly.");
}

void KIsdnDockConfig::configChanged()
{
	emit changed(true);
}

void KIsdnDockConfig::rcn()
{
	KProcess p;
	p << "redhat-config-network";
	// We need to reload ourselves when redhat-config-network is finished.
	// The interfaces might have changed.
	connect(&p, SIGNAL(processExited(KProcess *)), this, SLOT(load()));
	p.start(KProcess::DontCare);
}

void KIsdnDockConfig::druid()
{
	KProcess p;
	p << "internet-druid";
	// We need to reload ourselves when internet-druid is finished.
	// The interfaces might have changed.
	connect(&p, SIGNAL(processExited(KProcess *)), this, SLOT(load()));
	p.start(KProcess::DontCare);
}

